summaryrefslogtreecommitdiff
path: root/sql/sql_lex.h
diff options
context:
space:
mode:
authorunknown <brian@zim.(none)>2006-03-09 17:06:04 -0800
committerunknown <brian@zim.(none)>2006-03-09 17:06:04 -0800
commit8c3b4b14f1f8e92d978c7cd5d12f2d774d1c5159 (patch)
tree7ea3c61472ebb086c4b7ae9dc8224929e58e1743 /sql/sql_lex.h
parentf8e16cfb7830d2a23c98d949e5dd8542037a61ec (diff)
parent696367399bd1013b5db7701659117dde9297f08c (diff)
downloadmariadb-git-8c3b4b14f1f8e92d978c7cd5d12f2d774d1c5159.tar.gz
Merge zim.(none):/home/brian/mysql/mysql-5.0
into zim.(none):/home/brian/mysql/mysql-5.1-new sql/mysql_priv.h: Auto merged sql/mysqld.cc: Auto merged sql/sp.cc: Auto merged sql/sql_lex.cc: Auto merged sql/sql_lex.h: Auto merged sql/sql_parse.cc: Auto merged sql/sql_prepare.cc: Auto merged sql/sql_trigger.cc: Auto merged sql/sql_view.cc: Auto merged
Diffstat (limited to 'sql/sql_lex.h')
-rw-r--r--sql/sql_lex.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/sql/sql_lex.h b/sql/sql_lex.h
index c98255e7ecc..66f097a101c 100644
--- a/sql/sql_lex.h
+++ b/sql/sql_lex.h
@@ -757,7 +757,7 @@ typedef struct st_lex
const uchar *buf; /* The beginning of string, used by SPs */
const uchar *ptr,*tok_start,*tok_end,*end_of_query;
/* The values of tok_start/tok_end as they were one call of yylex before */
const uchar *tok_start_prev, *tok_end_prev;
char *length,*dec,*change,*name;
@@ -1119,7 +1119,7 @@ extern void lex_init(void);
extern void lex_free(void);
extern void lex_start(THD *thd, const uchar *buf, uint length);
extern void lex_end(LEX *lex);
-extern int yylex(void *arg, void *yythd);
+extern int MYSQLlex(void *arg, void *yythd);
extern pthread_key(LEX*,THR_LEX);
@@ -757,7 +757,7 @@ typedef struct st_lex
const uchar *buf; /* The beginning of string, used by SPs */
const uchar *ptr,*tok_start,*tok_end,*end_of_query;
- /* The values of tok_start/tok_end as they were one call of yylex before */
+ /* The values of tok_start/tok_end as they were one call of MYSQLlex before */
const uchar *tok_start_prev, *tok_end_prev;
char *length,*dec,*change,*name;